@@ -13,9 +13,9 @@ def create_deep_link(context, context_id, url='http://node.brightid.org', schema
     return deep_link
 
 
-def create_qr(deep_link):
+def create_qr(deep_link, scale=8):
     qr = pyqrcode.create(deep_link)
-    return qr.png_as_base64_str()
+    return qr.png_as_base64_str(scale=scale)
 
 
 def sign(op, private):
